==> haskell-hspec-smallcheck-0.5.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-FyYKjbeajToEkpgLzVEFy2
key: hspec-smallcheck-0.5.2-FyYKjbeajToEkpgLzVEFy2
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 6ba38d2a36527bd2289a02fea01f24de
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-FyYKjbeajToEkpgLzVEFy2
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    hspec-core-2.5.5-GQz0GZFprmixw75pGI27v
    smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             hspec-core-2.5.5-GQz0GZFprmixw75pGI27v=2d79cfefc5f2bd4024218505e216dbe0
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=bc47fa17892c8368ad5a2cdee65ad7b8
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.2-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-JpRsETxMc73rMh2vjFLG7
key: hspec-smallcheck-0.5.2-JpRsETxMc73rMh2vjFLG7
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 7424a7156cb7feba436c7a08f54f8096
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-JpRsETxMc73rMh2vjFLG7
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    hspec-core-2.5.5-JtKeMsWtF9L8hZENfYWIs4
    smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=b175aabb3dd9ae95a14a70d0ded5aa16
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=842aa1f6a3dc6ac6e201dfeb465a9bd8
             hspec-core-2.5.5-JtKeMsWtF9L8hZENfYWIs4=811312d1a0e6a2a1ce099e5ee30f15f0
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=bc47fa17892c8368ad5a2cdee65ad7b8
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
